from django.contrib import admin
from .models import InApp, Receipt, Response


class InAppAdmin(admin.ModelAdmin):
    list_display = (
        'quantity', 'product_id', 'transaction_id',
        'original_transaction_id', 'purchase_date', 'original_purchase_date', 'is_trial_period'
    )
    list_display_links = (
        'quantity', 'product_id', 'transaction_id',
        'original_transaction_id', 'purchase_date', 'original_purchase_date'
    )


admin.site.register(InApp, InAppAdmin)


class ReceiptAdmin(admin.ModelAdmin):
    list_display = (
        'receipt_type', 'adam_id', 'app_item_id', 'bundle_id', 'application_version', 'download_id',
        'version_external_identifier', 'receipt_creation_date', 'request_date', 'original_purchase_date', 'in_app'
    )
    list_display_links = (
        'receipt_type', 'adam_id', 'app_item_id', 'bundle_id', 'application_version', 'download_id',
        'version_external_identifier', 'receipt_creation_date', 'request_date', 'original_purchase_date', 'in_app'
    )


admin.site.register(Receipt, ReceiptAdmin)


class ResponseAdmin(admin.ModelAdmin):
    list_display = ('status', 'environment', 'receipt')
    list_display_links = ('status', 'environment', 'receipt')


admin.site.register(Response, ResponseAdmin)



from django.conf import settings
from .appstore import AppStoreValidator


def normal_receipt(receipt, sandbox):
    try:
        storekit_bundle_id = settings.STOREKIT_APP_BUNDLE_ID
    except AttributeError:
        raise AttributeError('Please set "STOREKIT_APP_BUNDLE_ID" in your settings.py')

    validator = AppStoreValidator(
        bundle_id=storekit_bundle_id,
        sandbox=sandbox
    )

    return validator.validate(
        receipt=receipt
    )


def subscribe_receipt(receipt, sandbox):
    try:
        storekit_app_bundle_id = settings.STOREKIT_APP_BUNDLE_ID
    except AttributeError:
        raise AttributeError('Please set "STOREKIT_APP_BUNDLE_ID" in your settings.py')

    try:
        storekit_purchased_secret = settings.STOREKIT_PURCHASED_SECRET
    except AttributeError:
        raise AttributeError('Please set "STOREKIT_PURCHASED_SECRET" in your settings.py')

    validator = AppStoreValidator(
        bundle_id=storekit_app_bundle_id,
        sandbox=sandbox
    )

    return validator.validate(
        receipt=receipt,
        password=storekit_purchased_secret
    )



# codeing: utf-8
from setuptools import setup, find_packages


NAME = 'django-ios-storekit'
VERSION = '1.0.3'


def read(filename):
    import os
    BASE_DIR = os.path.dirname(__file__)
    filename = os.path.join(BASE_DIR, filename)
    with open(filename, 'r') as f:
        return f.read()


def readlist(filename):
    rows = read(filename).split('\n')
    rows = [x.strip() for x in rows if x.strip()]
    return list(rows)


setup(
    name=NAME,
    version=VERSION,
    description='A Django plugin for iOS In-App Purchases.',
    long_description=read('README.rst'),
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    keyword='django ios in-app-purchases apple',
    author='nnsnodnb',
    author_email='ahr63_gej@me.com',
    url='https://github.com/nnsnodnb/django-ios-storekit',
    download_url='https://github.com/nnsnodnb/django-ios-storekit/tarball/master',
    license='MIT',
    packages=find_packages(),
    include_package_data=True,
    package_data={
        '': [
                'README.rst',
                'requirements.txt',
                'requirements-test.txt'
            ]
    },
    zip_safe=False,
    install_requires=readlist('requirements.txt'),
    test_suite='runtests.run_tests',
    tests_require=readlist('requirements-test.txt')
)
